"""Petey — The Easy PDF Extractor."""

from petey.schema import build_model, load_schema
from petey.extract import (
    extract,
    extract_async,
    extract_batch,
    extract_text,
    extract_text_pages,
    extract_pages_async,
    infer_schema,
    infer_schema_async,
    infer_schema_vision_async,
)

__all__ = [
    "build_model",
    "load_schema",
    "extract",
    "extract_async",
    "extract_batch",
    "extract_text",
    "extract_text_pages",
    "extract_pages_async",
    "infer_schema",
    "infer_schema_async",
    "infer_schema_vision_async",
]
